@@ -23,6 +23,7 @@
 #include "ephy-web-extension.h"
 #include "ephy-debug.h"
 #include "ephy-file-helpers.h"
+#include "ephy-settings.h"
 
 #pragma GCC diagnostic push
 #pragma GCC diagnostic ignored "-Wmissing-prototypes"
@@ -67,6 +68,9 @@ ephy_web_extension_shutdown (void)
 {
   if (extension)
     g_object_unref (extension);
+
+  ephy_settings_shutdown ();
+  ephy_file_helpers_shutdown ();
 }
 
 #pragma GCC diagnostic pop
