@@ -23,7 +23,7 @@
 
 #include "ephy-history-service-private.h"
 #include "ephy-history-types.h"
-#include "ephy-history-type-builtins.h"
+#include "ephy-lib-type-builtins.h"
 #include "ephy-sqlite-connection.h"
 
 #include <errno.h>
@@ -369,7 +369,7 @@ ephy_history_service_open_transaction (EphyHistoryService *self)
 
   ephy_sqlite_connection_begin_transaction (self->history_database, &error);
   if (error != NULL) {
-    g_error ("Could not open history database transaction: %s", error->message);
+    g_warning ("Could not open history database transaction: %s", error->message);
     g_error_free (error);
   }
 }
