@@ -32,7 +32,6 @@
 #include "ephy-location-entry.h"
 #include "ephy-shell.h"
 #include "ephy-title-widget.h"
-#include "ephy-uri-helpers.h"
 #include "ephy-widgets-type-builtins.h"
 
 #include <gdk/gdkkeysyms.h>
@@ -228,12 +227,11 @@ get_location_cb (EphyLocationEntry      *entry,
                  EphyLocationController *controller)
 {
   EphyEmbed *embed;
-  const char *address;
 
-  embed = ephy_embed_container_get_active_child (EPHY_EMBED_CONTAINER (controller->window));
-  address = ephy_web_view_get_address (ephy_embed_get_web_view (embed));
+  embed = ephy_embed_container_get_active_child
+            (EPHY_EMBED_CONTAINER (controller->window));
 
-  return ephy_embed_utils_is_no_show_address (address) ? NULL : ephy_uri_decode (address);
+  return g_strdup (ephy_web_view_get_address (ephy_embed_get_web_view (embed)));
 }
 
 static char *
@@ -408,8 +406,8 @@ ephy_location_controller_constructed (GObject *object)
 
   add_completion_actions (controller, EPHY_LOCATION_ENTRY (controller->title_widget));
 
-  g_signal_connect_object (controller->search_engine_manager, "changed",
-                           G_CALLBACK (search_engines_changed_cb), controller, 0);
+  g_signal_connect (controller->search_engine_manager, "changed",
+                    G_CALLBACK (search_engines_changed_cb), controller);
 
   g_object_bind_property (controller, "editable",
                           controller->title_widget, "editable",
