@@ -831,7 +831,10 @@ session_seems_sane (GList *windows)
        SoupURI *uri = soup_uri_new (url);
        if (uri) {
          soup_uri_free (uri);
-       } else {
+       }
+       /* Blank URLs can occur in some situations. Don't save them, but also
+        * do not torpedo the entire session as it's not a bug. */
+       else if (strcmp (url, "") != 0) {
          g_critical ("Refusing to save session due to invalid URL %s", url);
          return FALSE;
        }
@@ -1022,13 +1025,11 @@ static void
 restore_geometry (GtkWindow    *window,
                   GdkRectangle *geometry)
 {
-  if (geometry->x >= 0 && geometry->y >= 0) {
-    gtk_window_move (window, geometry->x, geometry->y);
-  }
+  if (geometry->x >= 0 && geometry->y >= 0)
+    ephy_window_set_default_position (EPHY_WINDOW (window), geometry->x, geometry->y);
 
-  if (geometry->width > 0 && geometry->height > 0) {
-    gtk_window_set_default_size (window, geometry->width, geometry->height);
-  }
+  if (geometry->width > 0 && geometry->height > 0)
+    ephy_window_set_default_size (EPHY_WINDOW (window), geometry->width, geometry->height);
 }
 
 typedef struct {
