@@ -47,11 +47,10 @@
 #include <glib/gi18n.h>
 #include <gtk/gtk.h>
 #include <JavaScriptCore/JavaScript.h>
+#include <json-glib/json-glib.h>
 #include <string.h>
 
-#ifdef ENABLE_SYNC
-#include <json-glib/json-glib.h>
-
+#if ENABLE_FIREFOX_SYNC
 #include "ephy-sync-crypto.h"
 #include "ephy-sync-secret.h"
 #include "ephy-sync-service.h"
@@ -116,7 +115,7 @@ struct _PrefsDialog {
   GHashTable *iso_639_table;
   GHashTable *iso_3166_table;
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
   /* sync */
   GtkWidget *sync_authenticate_box;
   GtkWidget *sync_sign_in_box;
@@ -133,7 +132,7 @@ struct _PrefsDialog {
   GtkWidget *notebook;
 };
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
 typedef struct {
   PrefsDialog *dialog;
   char        *email;
@@ -156,7 +155,7 @@ enum {
 
 G_DEFINE_TYPE (PrefsDialog, prefs_dialog, GTK_TYPE_DIALOG)
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
 static FxACallbackData *
 fxa_callback_data_new (PrefsDialog *dialog,
                        const char  *email,
@@ -225,7 +224,7 @@ prefs_dialog_finalize (GObject *object)
   g_hash_table_destroy (dialog->iso_639_table);
   g_hash_table_destroy (dialog->iso_3166_table);
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
   if (dialog->fxa_web_view != NULL) {
     webkit_user_content_manager_unregister_script_message_handler (dialog->fxa_manager,
                                                                    "accountsCommandHandler");
@@ -242,7 +241,7 @@ prefs_dialog_finalize (GObject *object)
   G_OBJECT_CLASS (prefs_dialog_parent_class)->finalize (object);
 }
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
 static void
 hide_fxa_iframe (PrefsDialog *dialog,
                  const char  *email)
@@ -639,7 +638,7 @@ prefs_dialog_class_init (PrefsDialogClass *klass)
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, lang_down_button);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, enable_spell_checking_checkbutton);
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
   /* sync */
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_authenticate_box);
   gtk_widget_class_bind_template_child (widget_class, PrefsDialog, sync_sign_in_box);
@@ -1199,7 +1198,7 @@ create_download_path_button (PrefsDialog *dialog)
 
   dir = ephy_file_get_downloads_dir ();
 
-  button = gtk_file_chooser_button_new (_("Select a Directory"),
+  button = gtk_file_chooser_button_new (_("Select a directory"),
                                         GTK_FILE_CHOOSER_ACTION_SELECT_FOLDER);
 
   gtk_file_chooser_set_current_folder (GTK_FILE_CHOOSER (button), dir);
@@ -1316,17 +1315,10 @@ new_tab_homepage_get_mapping (GValue   *value,
 static GVariant *
 new_tab_homepage_set_mapping (const GValue       *value,
                               const GVariantType *expected_type,
-                              gpointer           user_data)
+                              gpointer            user_data)
 {
-  PrefsDialog *dialog = EPHY_PREFS_DIALOG (user_data);
-
   if (!g_value_get_boolean (value))
     return NULL;
-
-  /* In case the new tab button is pressed while there's text in the custom homepage entry */
-  gtk_entry_set_text (GTK_ENTRY (dialog->custom_homepage_entry), "");
-  gtk_widget_set_sensitive (dialog->custom_homepage_entry, FALSE);
-
   return g_variant_new_string ("");
 }
 
@@ -1347,15 +1339,10 @@ blank_homepage_get_mapping (GValue   *value,
 static GVariant *
 blank_homepage_set_mapping (const GValue       *value,
                             const GVariantType *expected_type,
-                            gpointer           user_data)
+                            gpointer            user_data)
 {
-  PrefsDialog *dialog = EPHY_PREFS_DIALOG (user_data);
-
   if (!g_value_get_boolean (value))
     return NULL;
-
-  gtk_entry_set_text (GTK_ENTRY (dialog->custom_homepage_entry), "");
-
   return g_variant_new_string ("about:blank");
 }
 
@@ -1377,12 +1364,11 @@ custom_homepage_set_mapping (const GValue       *value,
                              const GVariantType *expected_type,
                              gpointer            user_data)
 {
-  PrefsDialog *dialog = EPHY_PREFS_DIALOG (user_data);
+  PrefsDialog *dialog = user_data;
   const char *setting;
 
   if (!g_value_get_boolean (value)) {
     gtk_widget_set_sensitive (dialog->custom_homepage_entry, FALSE);
-    gtk_entry_set_text (GTK_ENTRY (dialog->custom_homepage_entry), "");
     return NULL;
   }
 
@@ -1393,7 +1379,6 @@ custom_homepage_set_mapping (const GValue       *value,
     return NULL;
 
   gtk_entry_set_text (GTK_ENTRY (dialog->custom_homepage_entry), setting);
-
   return g_variant_new_string (setting);
 }
 
@@ -1401,15 +1386,8 @@ static void
 custom_homepage_entry_changed (GtkEntry    *entry,
                                PrefsDialog *dialog)
 {
-  if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->custom_homepage_radiobutton))) {
-    g_settings_set_string (EPHY_SETTINGS_MAIN, EPHY_PREFS_HOMEPAGE_URL,
-                           gtk_entry_get_text (entry));
-  } else if ((gtk_entry_get_text (entry) != NULL) &&
-             gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON (dialog->new_tab_homepage_radiobutton))) {
-    g_settings_set_string (EPHY_SETTINGS_MAIN, EPHY_PREFS_HOMEPAGE_URL, gtk_entry_get_text (entry));
-    gtk_widget_set_sensitive (dialog->custom_homepage_entry, TRUE);
-    gtk_widget_grab_focus (dialog->custom_homepage_entry);
-  }
+  g_settings_set_string (EPHY_SETTINGS_MAIN, EPHY_PREFS_HOMEPAGE_URL,
+                         gtk_entry_get_text (entry));
 }
 
 static void
@@ -1458,7 +1436,7 @@ setup_general_page (PrefsDialog *dialog)
                                 G_SETTINGS_BIND_DEFAULT,
                                 new_tab_homepage_get_mapping,
                                 new_tab_homepage_set_mapping,
-                                dialog,
+                                NULL,
                                 NULL);
   g_settings_bind_with_mapping (settings,
                                 EPHY_PREFS_HOMEPAGE_URL,
@@ -1467,7 +1445,7 @@ setup_general_page (PrefsDialog *dialog)
                                 G_SETTINGS_BIND_DEFAULT,
                                 blank_homepage_get_mapping,
                                 blank_homepage_set_mapping,
-                                dialog,
+                                NULL,
                                 NULL);
   g_settings_bind_with_mapping (settings,
                                 EPHY_PREFS_HOMEPAGE_URL,
@@ -1654,7 +1632,7 @@ setup_language_page (PrefsDialog *dialog)
   create_language_section (dialog);
 }
 
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
 static void
 setup_sync_page (PrefsDialog *dialog)
 {
@@ -1710,7 +1688,7 @@ prefs_dialog_init (PrefsDialog *dialog)
   setup_fonts_page (dialog);
   setup_stored_data_page (dialog);
   setup_language_page (dialog);
-#ifdef ENABLE_SYNC
+#if ENABLE_FIREFOX_SYNC
   if (mode != EPHY_EMBED_SHELL_MODE_APPLICATION) {
     setup_sync_page (dialog);
 
